var NAVTREEINDEX0 =
{
"_animation.html":[1,8],
"_animation.html#Animation-State":[1,8,0],
"_animation.html#Combined-Hardware-Skinning":[1,8,3,5,0],
"_animation.html#Combining-Skeletal-and-Vertex-Animation":[1,8,3,5],
"_animation.html#Morph-Animation":[1,8,3,3],
"_animation.html#Numeric-Value-Animation":[1,8,4],
"_animation.html#Pose-Animation":[1,8,3,4],
"_animation.html#SceneNode-Animation":[1,8,2],
"_animation.html#Skeletal-Animation":[1,8,1],
"_animation.html#Submesh-Splits":[1,8,3,5,1],
"_animation.html#Vertex-Animation":[1,8,3],
"_animation.html#autotoc_md54":[1,8,3,0],
"_animation.html#autotoc_md55":[1,8,3,1],
"_animation.html#autotoc_md56":[1,8,3,2],
"_animation.html#autotoc_md57":[1,8,4,0],
"_animation.html#autotoc_md58":[1,8,4,1],
"_compositor-_scripts.html":[1,3,5],
"_compositor-_scripts.html#Applying-a-Compositor":[1,3,5,4],
"_compositor-_scripts.html#Clear-Section":[1,3,5,3,2],
"_compositor-_scripts.html#Compositor-API":[1,3,5,5],
"_compositor-_scripts.html#Compositor-Fundamentals":[1,3,5,0],
"_compositor-_scripts.html#Compositor-Passes":[1,3,5,3],
"_compositor-_scripts.html#Compositor-Target-Passes":[1,3,5,2],
"_compositor-_scripts.html#Compositor-Techniques":[1,3,5,1],
"_compositor-_scripts.html#Stencil-Section":[1,3,5,3,3],
"_compositor-_scripts.html#autotoc_md64":[1,3,5,1,1],
"_compositor-_scripts.html#autotoc_md65":[1,3,5,1,2],
"_compositor-_scripts.html#autotoc_md66":[1,3,5,1,3],
"_compositor-_scripts.html#autotoc_md67":[1,3,5,2,0],
"_compositor-_scripts.html#autotoc_md68":[1,3,5,2,1],
"_compositor-_scripts.html#autotoc_md69":[1,3,5,2,2],
"_compositor-_scripts.html#autotoc_md70":[1,3,5,2,3],
"_compositor-_scripts.html#autotoc_md71":[1,3,5,2,4],
"_compositor-_scripts.html#autotoc_md72":[1,3,5,2,5],
"_compositor-_scripts.html#autotoc_md73":[1,3,5,3,0],
"_compositor-_scripts.html#autotoc_md74":[1,3,5,3,0,0],
"_compositor-_scripts.html#autotoc_md75":[1,3,5,3,0,1],
"_compositor-_scripts.html#autotoc_md76":[1,3,5,3,0,2],
"_compositor-_scripts.html#autotoc_md77":[1,3,5,3,0,3],
"_compositor-_scripts.html#autotoc_md78":[1,3,5,3,0,4],
"_compositor-_scripts.html#autotoc_md79":[1,3,5,3,1],
"_compositor-_scripts.html#autotoc_md80":[1,3,5,3,1,0],
"_compositor-_scripts.html#autotoc_md81":[1,3,5,3,1,1],
"_compositor-_scripts.html#autotoc_md82":[1,3,5,3,1,2],
"_compositor-_scripts.html#autotoc_md83":[1,3,5,3,1,3],
"_compositor-_scripts.html#autotoc_md84":[1,3,5,3,2,0],
"_compositor-_scripts.html#autotoc_md85":[1,3,5,3,2,1],
"_compositor-_scripts.html#autotoc_md86":[1,3,5,3,2,2],
"_compositor-_scripts.html#autotoc_md87":[1,3,5,3,2,3],
"_compositor-_scripts.html#autotoc_md88":[1,3,5,3,3,0],
"_compositor-_scripts.html#autotoc_md89":[1,3,5,3,3,1],
"_compositor-_scripts.html#autotoc_md90":[1,3,5,3,3,2],
"_compositor-_scripts.html#autotoc_md91":[1,3,5,3,3,3],
"_compositor-_scripts.html#autotoc_md92":[1,3,5,3,3,4],
"_compositor-_scripts.html#autotoc_md93":[1,3,5,3,3,5],
"_compositor-_scripts.html#autotoc_md94":[1,3,5,3,3,6],
"_compositor-_scripts.html#autotoc_md95":[1,3,5,3,3,7],
"_compositor-_scripts.html#compositor-texture":[1,3,5,1,0],
"_cross-platform-_shaders.html":[1,10],
"_cross-platform-_shaders.html#OgreUnifiedShader":[1,10,1],
"_cross-platform-_shaders.html#autotoc_md204":[1,10,0],
"_cross-platform-_shaders.html#autotoc_md205":[1,10,2],
"_external-_texture-_sources.html":[2,13],
"_external-_texture-_sources.html#autotoc_md293":[2,13,0],
"_external-_texture-_sources.html#autotoc_md294":[2,13,1],
"_external-_texture-_sources.html#autotoc_md295":[2,13,2],
"_external-_texture-_sources.html#autotoc_md296":[2,13,3],
"_external-_texture-_sources.html#autotoc_md297":[2,13,4],
"_font-_definition-_scripts.html":[1,3,8],
"_font-_definition-_scripts.html#autotoc_md108":[1,3,8,0],
"_font-_definition-_scripts.html#autotoc_md109":[1,3,8,1],
"_hardware-_buffers.html":[1,6],
"_hardware-_buffers.html#Binding-the-Vertex-Buffer":[1,6,5,4],
"_hardware-_buffers.html#Buffer-Usage":[1,6,1],
"_hardware-_buffers.html#Colour-channels":[1,6,8,3,0],
"_hardware-_buffers.html#Creating-a-texture":[1,6,8,0],
"_hardware-_buffers.html#Creating-the-Vertex-Buffer":[1,6,5,3],
"_hardware-_buffers.html#Cube-map-textures":[1,6,8,2],
"_hardware-_buffers.html#Data-Transfer":[1,6,3],
"_hardware-_buffers.html#Direct-memory-locking":[1,6,7,1,1],
"_hardware-_buffers.html#Getting-a-PixelBuffer":[1,6,8,1],
"_hardware-_buffers.html#Hardware-Index-Buffers":[1,6,6],
"_hardware-_buffers.html#Hardware-Pixel-Buffers":[1,6,7],
"_hardware-_buffers.html#Hardware-Vertex-Buffers":[1,6,5],
"_hardware-_buffers.html#Locking-buffers":[1,6,3,1],
"_hardware-_buffers.html#Pixel-Formats":[1,6,8,3],
"_hardware-_buffers.html#Pixel-boxes":[1,6,7,0],
"_hardware-_buffers.html#Practical-Buffer-Tips":[1,6,4],
"_hardware-_buffers.html#Shadow-Buffers":[1,6,2],
"_hardware-_buffers.html#Textures":[1,6,8],
"_hardware-_buffers.html#The-Hardware-Buffer-Manager":[1,6,0],
"_hardware-_buffers.html#The-IndexData-class":[1,6,6,0],
"_hardware-_buffers.html#The-VertexData-class":[1,6,5,0],
"_hardware-_buffers.html#Updating-Index-Buffers":[1,6,6,2],
"_hardware-_buffers.html#Updating-Pixel-Buffers":[1,6,7,1],
"_hardware-_buffers.html#Updating-Vertex-Buffers":[1,6,5,5],
"_hardware-_buffers.html#Vertex-Buffer-Bindings":[1,6,5,2],
"_hardware-_buffers.html#Vertex-Declarations":[1,6,5,1],
"_hardware-_buffers.html#autotoc_md240":[1,6,3,0],
"_hardware-_buffers.html#autotoc_md241":[1,6,3,1,0],
"_hardware-_buffers.html#autotoc_md242":[1,6,4,0],
"_hardware-_buffers.html#autotoc_md243":[1,6,6,1],
"_hardware-_buffers.html#blitFromMemory":[1,6,7,1,0],
"_high-level-_programs.html":[1,3,4],
"_high-level-_programs.html#Assembler-Shaders":[1,3,4,5],
"_high-level-_programs.html#Binding-vertex-attributes":[1,3,4,2,0],
"_high-level-_programs.html#Cg":[1,3,4,3],
"_high-level-_programs.html#Declaring-Shared-Parameters":[1,3,4,9],
"_high-level-_programs.html#Default-Program-Parameters":[1,3,4,0],
"_high-level-_programs.html#GLSL":[1,3,4,2],
"_high-level-_programs.html#GLSL-Mesh-Shaders":[1,3,4,2,1],
"_high-level-_programs.html#GLSL-Texture-Samplers":[1,3,4,2,2],
"_high-level-_programs.html#GpuProgram-API":[1,3,4,16],
"_high-level-_programs.html#HLSL":[1,3,4,4],
"_high-level-_programs.html#Instancing-in-Vertex-Programs":[1,3,4,11],
"_high-level-_programs.html#Legacy-GLSL-features":[1,3,4,2,6],
"_high-level-_programs.html#Matrix-parameters":[1,3,4,2,3],
"_high-level-_programs.html#Morph-Animation-in-Vertex-Programs":[1,3,4,13],
"_high-level-_programs.html#Pose-Animation-in-Vertex-Programs":[1,3,4,14],
"_high-level-_programs.html#Preprocessor-definitions":[1,3,4,1,0],
"_high-level-_programs.html#Program-Parameter-Specification":[1,3,4,8],
"_high-level-_programs.html#Shadows-and-Vertex-Programs":[1,3,4,10],
"_high-level-_programs.html#Skeletal-Animation-in-Vertex-Programs":[1,3,4,12],
"_high-level-_programs.html#Specifying-Named-Constants-for-Assembler-Shaders":[1,3,4,5,0],
"_high-level-_programs.html#Transform-Feedback-Varyings":[1,3,4,2,5],
"_high-level-_programs.html#Unified-High_002dlevel-Programs":[1,3,4,7],
"_high-level-_programs.html#Uniform-Buffers":[1,3,4,2,4],
"_high-level-_programs.html#Vertex-Texture-Fetch":[1,3,4,15],
"_high-level-_programs.html#autotoc_md188":[1,3,4,1],
"_high-level-_programs.html#autotoc_md189":[1,3,4,1,1],
"_high-level-_programs.html#autotoc_md190":[1,3,4,2,6,0],
"_high-level-_programs.html#autotoc_md191":[1,3,4,2,6,1],
"_high-level-_programs.html#autotoc_md192":[1,3,4,2,6,2],
"_high-level-_programs.html#autotoc_md193":[1,3,4,2,6,3],
"_high-level-_programs.html#autotoc_md194":[1,3,4,8,0],
"_high-level-_programs.html#autotoc_md195":[1,3,4,8,1],
"_high-level-_programs.html#autotoc_md196":[1,3,4,8,2],
"_high-level-_programs.html#autotoc_md197":[1,3,4,8,3],
"_high-level-_programs.html#autotoc_md198":[1,3,4,8,4],
"_high-level-_programs.html#autotoc_md199":[1,3,4,9,0],
"_high-level-_programs.html#autotoc_md200":[1,3,4,15,0],
"_high-level-_programs.html#autotoc_md201":[1,3,4,15,1],
"_high-level-_programs.html#autotoc_md202":[1,3,4,15,2],
"_high-level-_programs.html#autotoc_md203":[1,3,4,15,3],
"_high-level-_programs.html#multi-language-programs":[1,3,4,6],
"_high_py_8py.html":[8,0,0,6,0],
"_instancing.html":[1,9],
"_instancing.html#Instance-Manager":[1,9,1],
"_instancing.html#Static-Geometry":[1,9,0],
"_instancing.html#Static-Geometry-vs-Instancing":[1,9,2],
"_introduction.html":[1,0],
"_introduction.html#autotoc_md25":[1,0,0],
"_introduction.html#autotoc_md26":[1,0,1],
"_material-_scripts.html":[1,3,3],
"_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a":[1,3,3,7],
"_material-_scripts.html#Identifying-Texture-Units-to-override-values":[1,3,3,8],
"_material-_scripts.html#Material":[1,3,3,0],
"_material-_scripts.html#Passes":[1,3,3,2],
"_material-_scripts.html#Samplers":[1,3,3,5],
"_material-_scripts.html#Techniques":[1,3,3,1],
"_material-_scripts.html#Texture-Units":[1,3,3,4],
"_material-_scripts.html#Using-Vertex_002fGeometry_002fFragment-Programs-in-a-Pass":[1,3,3,6],
"_material-_scripts.html#autotoc_md110":[1,3,3,0,0],
"_material-_scripts.html#autotoc_md111":[1,3,3,0,1],
"_material-_scripts.html#autotoc_md112":[1,3,3,0,2],
"_material-_scripts.html#autotoc_md113":[1,3,3,0,3],
"_material-_scripts.html#autotoc_md114":[1,3,3,0,4],
"_material-_scripts.html#autotoc_md115":[1,3,3,0,5],
"_material-_scripts.html#autotoc_md116":[1,3,3,1,0],
"_material-_scripts.html#autotoc_md117":[1,3,3,1,1],
"_material-_scripts.html#autotoc_md118":[1,3,3,1,2],
"_material-_scripts.html#autotoc_md119":[1,3,3,1,3],
"_material-_scripts.html#autotoc_md120":[1,3,3,1,4],
"_material-_scripts.html#autotoc_md121":[1,3,3,3],
"_material-_scripts.html#autotoc_md122":[1,3,3,3,0],
"_material-_scripts.html#autotoc_md123":[1,3,3,3,1],
"_material-_scripts.html#autotoc_md124":[1,3,3,3,2],
"_material-_scripts.html#autotoc_md125":[1,3,3,3,3],
"_material-_scripts.html#autotoc_md126":[1,3,3,3,4],
"_material-_scripts.html#autotoc_md127":[1,3,3,3,5],
"_material-_scripts.html#autotoc_md128":[1,3,3,3,6],
"_material-_scripts.html#autotoc_md129":[1,3,3,3,7],
"_material-_scripts.html#autotoc_md130":[1,3,3,3,8],
"_material-_scripts.html#autotoc_md131":[1,3,3,3,9],
"_material-_scripts.html#autotoc_md132":[1,3,3,3,10],
"_material-_scripts.html#autotoc_md133":[1,3,3,3,11],
"_material-_scripts.html#autotoc_md134":[1,3,3,3,12],
"_material-_scripts.html#autotoc_md135":[1,3,3,3,13],
"_material-_scripts.html#autotoc_md136":[1,3,3,3,14],
"_material-_scripts.html#autotoc_md137":[1,3,3,3,15],
"_material-_scripts.html#autotoc_md138":[1,3,3,3,16],
"_material-_scripts.html#autotoc_md139":[1,3,3,3,18],
"_material-_scripts.html#autotoc_md140":[1,3,3,3,19],
"_material-_scripts.html#autotoc_md141":[1,3,3,3,20],
"_material-_scripts.html#autotoc_md142":[1,3,3,3,21],
"_material-_scripts.html#autotoc_md143":[1,3,3,3,22],
"_material-_scripts.html#autotoc_md144":[1,3,3,3,23],
"_material-_scripts.html#autotoc_md145":[1,3,3,3,24],
"_material-_scripts.html#autotoc_md146":[1,3,3,3,25],
"_material-_scripts.html#autotoc_md147":[1,3,3,3,26],
"_material-_scripts.html#autotoc_md148":[1,3,3,3,27],
"_material-_scripts.html#autotoc_md149":[1,3,3,3,28],
"_material-_scripts.html#autotoc_md150":[1,3,3,3,30],
"_material-_scripts.html#autotoc_md151":[1,3,3,3,31],
"_material-_scripts.html#autotoc_md152":[1,3,3,3,32],
"_material-_scripts.html#autotoc_md153":[1,3,3,3,33],
"_material-_scripts.html#autotoc_md154":[1,3,3,3,34],
"_material-_scripts.html#autotoc_md155":[1,3,3,3,35],
"_material-_scripts.html#autotoc_md156":[1,3,3,4,0],
"_material-_scripts.html#autotoc_md157":[1,3,3,4,1],
"_material-_scripts.html#autotoc_md158":[1,3,3,4,2],
"_material-_scripts.html#autotoc_md159":[1,3,3,4,3],
"_material-_scripts.html#autotoc_md160":[1,3,3,4,4],
"_material-_scripts.html#autotoc_md161":[1,3,3,4,5],
"_material-_scripts.html#autotoc_md162":[1,3,3,4,6],
"_material-_scripts.html#autotoc_md163":[1,3,3,4,7],
"_material-_scripts.html#autotoc_md164":[1,3,3,4,8],
"_material-_scripts.html#autotoc_md165":[1,3,3,4,9],
"_material-_scripts.html#autotoc_md166":[1,3,3,4,10],
"_material-_scripts.html#autotoc_md167":[1,3,3,4,11],
"_material-_scripts.html#autotoc_md168":[1,3,3,4,12],
"_material-_scripts.html#autotoc_md169":[1,3,3,4,13],
"_material-_scripts.html#autotoc_md170":[1,3,3,4,14],
"_material-_scripts.html#autotoc_md171":[1,3,3,4,15],
"_material-_scripts.html#autotoc_md172":[1,3,3,4,16],
"_material-_scripts.html#autotoc_md173":[1,3,3,4,17],
"_material-_scripts.html#autotoc_md174":[1,3,3,4,18],
"_material-_scripts.html#autotoc_md175":[1,3,3,4,19],
"_material-_scripts.html#autotoc_md176":[1,3,3,4,20],
"_material-_scripts.html#autotoc_md177":[1,3,3,4,21],
"_material-_scripts.html#autotoc_md178":[1,3,3,5,0],
"_material-_scripts.html#autotoc_md179":[1,3,3,5,1],
"_material-_scripts.html#autotoc_md180":[1,3,3,5,2],
"_material-_scripts.html#autotoc_md181":[1,3,3,5,3],
"_material-_scripts.html#autotoc_md182":[1,3,3,5,3,0],
"_material-_scripts.html#autotoc_md183":[1,3,3,5,3,1],
"_material-_scripts.html#autotoc_md184":[1,3,3,5,4],
"_material-_scripts.html#autotoc_md185":[1,3,3,5,5],
"_material-_scripts.html#autotoc_md186":[1,3,3,5,6],
"_material-_scripts.html#autotoc_md187":[1,3,3,5,7],
"_material-_scripts.html#illumination_005fstage":[1,3,3,3,17],
"_material-_scripts.html#iteration":[1,3,3,3,29],
"_mesh-_tools.html":[1,5],
"_mesh-_tools.html#AssimpConverter":[1,5,2],
"_mesh-_tools.html#Exporters":[1,5,3],
"_mesh-_tools.html#MeshUpgrader":[1,5,1],
"_mesh-_tools.html#XMLConverter":[1,5,0],
"_mesh-_tools.html#autotoc_md34":[1,5,3,1],
"_mesh-_tools.html#empty-material-names":[1,5,3,0],
"_numpy_8py.html":[8,0,0,6,1]
};
